@@ -3,7 +3,7 @@ package Toolforge::MixNMatch::Struct;
 use strict;
 use warnings;
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 1;
 
@@ -28,15 +28,15 @@ This distributions is set of basic conversions from/to Toolforge Mix'n'match too
 
 =item L<Toolforge::MixNMatch::Struct::Catalog>
 
-TODO
+Mix'n'match catalog structure serialization.
 
 =item L<Toolforge::MixNMatch::Struct::User>
 
-TODO
+Mix'n'match user structure serialization.
 
 =item L<Toolforge::MixNMatch::Struct::YearMonth>
 
-TODO
+Mix'n'match year/month structure serialization.
 
 =back
 
@@ -58,6 +58,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
